#ifndef INCLUDE_RTABLE_H
#define INCLUDE_RTABLE_H

/* system standard headers */
#include <netinet/in.h>

/* project specific headers */
#include <project3/include/types.h>
#include <project3/include/route.h>
#include <project3/include/global.h>

/* your own headers */

struct route_entry {
    struct route_entry *next;

    struct sockaddr_in rte_dst;	        /* destination, only sin_addr.s_addr 
					   field is used in project */
    u_int32_t	       rte_index;	/* interface index */
};

/* Initializes the route table data structures 
 */
void rt_init();  


/* Adds or deletes a route table entry
 * Returns SUCCESS on when no error occurs, FAILURE otherwise
 */
int rt_change(struct rt_info rt);
int rt_add_entry(uint32_t dest, int if_index);
int rt_del_entry(uint32_t dest);


/* Finds a route table entry based on dest IP address.
 * Return SUCCESS if a route if found.  In this case, the if_index values is set by the function.
 * Return FAILURE if no route is found.
 */
int rt_lookup_dest(uint32_t dest, int *if_index);

#endif
